@@ -2,4 +2,6 @@ ble_chars = [
     '0000ff01-0000-1000-8000-00805f9b34fb', # LithiumBatteryPCB adapter: read/notify
     '0000ff02-0000-1000-8000-00805f9b34fb', # LithiumBatteryPCB adapter: write
     '0000ffe1-0000-1000-8000-00805f9b34fb', # TI CC245x (HM-10, HM-11)
+    '6e400002-b5a3-f393-e0a9-e50e24dcca9e', # Nordic UART Service write
+    '6e400003-b5a3-f393-e0a9-e50e24dcca9e', # Nordic UART Service notify
 ]
\ No newline at end of file
